@@ -154,6 +154,25 @@ pubmed  <- function(..., disp=c("data","browser"),
     }
 }
 
+## A replacement for RCurl::getURL()
+##
+## Oct 13, 2020: RCurl::getURL() started to fail recently on Windows for
+## some HTTPS requests e.g. we started to see the following error on all
+## the Bioconductor Windows build machines (tokay1, riesling1, tokay2):
+##   > library(RCurl)
+##   > query <- "https://www.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=gene&to$
+##   > doc <- RCurl::getURL(query)
+##   Error in function (type, msg, asError = TRUE)  :
+##     error:1407742E:SSL routines:SSL23_GET_SERVER_HELLO:tlsv1 alert protocol version
+## The reason is not clear but we suspect a server-side issue with the SSL
+## certificate that only manifests itself with RCurl::getURL() on Windows.
+## httr::GET() doesn't seem to be affected so starting with annotate 1.67.2
+## accessionToUID() and blastSequences() use this instead of RCurl::getURL().
+getURL2 <- function(url)
+{
+    response <- httr::GET(url)
+    rawToChar(response$content)
+}
 
 accessionToUID <- function(...,db=c("genbank","pubmed")) {
     #require(XML)
@@ -178,7 +197,8 @@ accessionToUID <- function(...,db=c("genbank","pubmed")) {
                    "&tool=bioconductor&term=",accNum,sep="")
 
     ## parse using XML package
-    doc <- xmlParse(getURL(query))
+    Sys.sleep(0.15)  # avoid HTTP Error 429 "Too Many Requests"
+    doc <- xmlParse(getURL2(query))  # RCurl::getURL() has issues, see above
     res <- xpathApply(doc=doc, path="/eSearchResult/IdList/Id",
                       fun=xmlValue)
     
@@ -199,6 +219,7 @@ accessionToUID <- function(...,db=c("genbank","pubmed")) {
 
     ## get the XML file contents from URL, and remove extra
     ## text strings before <xml...
+    Sys.sleep(0.15)  # avoid HTTP Error 429 "Too Many Requests"
     query <- paste(scan(query, what="", sep="\n"), "\n", collapse="\n")
     query <- sub("^[^<]*<(.*)", "<\\1",query)
 
